=============================
:mod:`oujago.nn.keras_resnet`
=============================

.. automodule:: oujago.nn.keras_resnet

.. autosummary::

    handle_dim_order
    resnet18
    resnet34
    resnet50
    resnet101
    resnet152


Detailed Description
--------------------

.. autofunction:: handle_dim_order

.. autofunction:: resnet18

.. autofunction:: resnet34

.. autofunction:: resnet50

.. autofunction:: resnet101

.. autofunction:: resnet152


